@@ -89,7 +89,7 @@ namespace msXpSlibmass
 		:
 			QObject(engine), QScriptClass(engine)
 	{
-		qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 		qScriptRegisterMetaType<MassSpectrum>(engine, toScriptValue, fromScriptValue);
 
@@ -137,7 +137,7 @@ namespace msXpSlibmass
 	QScriptValue
 		MassSpectrumJs::prototype() const
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__;
 			return proto;
 		}
 
@@ -145,7 +145,7 @@ namespace msXpSlibmass
 	QScriptValue
 		MassSpectrumJs::constructor()
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			return ctor;
 		}
@@ -162,7 +162,7 @@ namespace msXpSlibmass
 	QScriptValue
 		MassSpectrumJs::newInstance()
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			MassSpectrum massSpectrum;
 
@@ -184,7 +184,7 @@ namespace msXpSlibmass
 	QScriptValue
 		MassSpectrumJs::newInstance(const QString &title)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			MassSpectrum massSpectrum(title);
 
@@ -218,7 +218,7 @@ namespace msXpSlibmass
 	QScriptValue
 		MassSpectrumJs::newInstance(const Trace &other)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			// We need to first create a mass spectrum object initialized using other
 			// so that the script object will actually be a MassSpectrum object and
@@ -274,7 +274,7 @@ namespace msXpSlibmass
 	QScriptValue
 		MassSpectrumJs::newInstance(const MassSpectrum &other)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			QScriptValue data = engine()->newVariant(QVariant::fromValue(other));
 
@@ -304,8 +304,8 @@ namespace msXpSlibmass
 		MassSpectrumJs::queryProperty(const QScriptValue &object,
 				const QScriptString &name, QueryFlags flags, uint *id)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "with name:" << name;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "with name:" << name;
 
 			MassSpectrum *massSpectrum = qscriptvalue_cast<MassSpectrum *>(object.data());
 
@@ -375,8 +375,8 @@ namespace msXpSlibmass
 
 			qint32 index = name.toArrayIndex(&isArrayIndex);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				"index is" << index << "and isArrayIndex is" << isArrayIndex;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//"index is" << index << "and isArrayIndex is" << isArrayIndex;
 
 			if(!isArrayIndex)
 			{
@@ -579,7 +579,7 @@ namespace msXpSlibmass
 			}
 			else
 			{
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 				qint32 index = id;
 
@@ -637,7 +637,7 @@ namespace msXpSlibmass
 		MassSpectrumJs::setProperty(QScriptValue &object, const QScriptString &name,
 				uint id, const QScriptValue &value)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			MassSpectrum *massSpectrum = qscriptvalue_cast<MassSpectrum *>(object.data());
 
@@ -704,15 +704,15 @@ namespace msXpSlibmass
 	QScriptValue
 		MassSpectrumJs::construct(QScriptContext *ctx, QScriptEngine *)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" ;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" ;
 
 			MassSpectrumJs *cls = qscriptvalue_cast<MassSpectrumJs*>(ctx->callee().data());
 
 			if (!cls)
 				return QScriptValue();
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Found the MassSpectrumJs class.";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "Found the MassSpectrumJs class.";
 
 			int argCount = ctx->argumentCount();
 
@@ -724,15 +724,15 @@ namespace msXpSlibmass
 
 				if(variant.userType() == QMetaType::type("msXpSlibmass::MassSpectrum"))
 				{
-					qDebug() << __FILE__ << __LINE__ << __FUNCTION__<< "()"
-						<< "The argument passed to the constructor is a MassSpectrum.";
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__<< "()"
+						//<< "The argument passed to the constructor is a MassSpectrum.";
 
 					return cls->newInstance(qscriptvalue_cast<MassSpectrum>(arg));
 				}
 				else if(variant.userType() == QMetaType::type("msXpSlibmass::Trace"))
 				{
-					qDebug() << __FILE__ << __LINE__ << __FUNCTION__<< "()"
-						<< "The argument passed to the constructor is a Trace.";
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__<< "()"
+						//<< "The argument passed to the constructor is a Trace.";
 
 					return cls->newInstance(qscriptvalue_cast<Trace>(arg));
 				}
