@@ -467,12 +467,7 @@ namespace msXpSlibmass
 
 			// Finally, do the work.
 
-			QString *text = thisMassSpectrum()->asText(rangeStart, rangeEnd);
-
-			QString result = *text;
-			delete text;
-
-			return result;
+			return thisMassSpectrum()->asText(rangeStart, rangeEnd);
 		}
 
 	/*/js/
