@@ -1,38 +1,39 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
  */
 
 
 
 
+
 /////////////////////// Qt includes
 #include <QSysInfo>
 #include <QString>
@@ -274,7 +275,7 @@ namespace msXpSmassXpert
 			 * #define MSXPERTSUITE_DATA_DIR C:/Program Files/msxpertsuite/data
 			 * #define MSXPERTSUITE_DOC_DIR C:/Program Files/msxpertsuite/doc/
 			 *
-			 * This means that for the massxpert module, the data will be copied as 
+			 * This means that for the massxpert module, the data will be copied as
 			 * C:/Program Files/msxpertsuite/data/massxpert, with the data immediately
 			 * in that directory, not in a 'data' subdirectory.
 			 */
@@ -286,7 +287,7 @@ namespace msXpSmassXpert
 			 * #define MSXPERTSUITE_DATA_DIR /usr/local/share/msxpertsuite
 			 * #define MSXPERTSUITE_DOC_DIR: /usr/local/share/doc/msxpertsuite/
 			 *
-			 * This means that for the massxpert module, the data will be copied as 
+			 * This means that for the massxpert module, the data will be copied as
 			 * /usr/local/share/msxpertsuite/massxpert with the data immediately in
 			 * that directory, not in a 'data' subdirectory.
 			 */
@@ -306,10 +307,10 @@ namespace msXpSmassXpert
 
 			CFURLRef bundleRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
 
-			CFStringRef macPath = 
+			CFStringRef macPath =
 				CFURLCopyFileSystemPath(bundleRef, kCFURLPOSIXPathStyle);
 
-			QString bundleDir = 
+			QString bundleDir =
 				CFStringGetCStringPtr(macPath, CFStringGetSystemEncoding());
 
 			CFRelease(bundleRef);
@@ -338,7 +339,7 @@ namespace msXpSmassXpert
 			// 1. The QSettings-based configuration is tested first because the user
 			// might have moved the data away from the original locations, and then
 			// set the new location in the QSettings configuration system.
-			// 
+			//
 			// 2. If the above solution fails, then we test the true config.h-based
 			// configuration, since this is where the data are installed initially.
 
@@ -372,8 +373,6 @@ namespace msXpSmassXpert
 			}
 			else
 			{
-				/////// From the config.h file
-
 				if(QSysInfo::productType() == "osx" || QSysInfo::productType() == "macos")
 				{
 					// Well, if we are on MacOSX, then we need to know where the bundle is
@@ -382,18 +381,21 @@ namespace msXpSmassXpert
 
 					testDir.setPath(QString("%1/../Resources/data").arg(QCoreApplication::applicationDirPath()));
 
-					//QMessageBox::information(this, 
+					//QMessageBox::information(this,
 					//"dir path",
 					//QCoreApplication::applicationDirPath(), QMessageBox::Ok);
 				}
 				else
 				{
+					/////// From the config.h file
+
+
 					// On UNIX, that would be /usr/local/share/msxpertsuite/<modulename>
 					// that is, /usr/local/share/msxpertsuite/massxpert, for example.
 					testDir.setPath(QString("%1").arg(MSXPERTSUITE_DATA_DIR));
 				}
 
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
 					<< "dir: " << QString("%1").arg(MSXPERTSUITE_DATA_DIR);
 
 				// The path must be absolute and must exist.
@@ -417,13 +419,13 @@ namespace msXpSmassXpert
 				}
 			}
 
-			//QMessageBox::information(this, 
-					//"data dir path",
-					//finalDir.absolutePath(), QMessageBox::Ok);
+			//QMessageBox::information(this,
+			//"data dir path",
+			//finalDir.absolutePath(), QMessageBox::Ok);
 
-			//QMessageBox::information(this, 
-					//"module",
-					//m_moduleName, QMessageBox::Ok);
+			//QMessageBox::information(this,
+			//"module",
+			//m_moduleName, QMessageBox::Ok);
 
 			// And now craft the ConfigSetting instance:
 
@@ -451,13 +453,28 @@ namespace msXpSmassXpert
 			}
 			else
 			{
-				/////// From the config.h file
+				if(QSysInfo::productType() == "osx" || QSysInfo::productType() == "macos")
+				{
+					// Well, if we are on MacOSX, then we need to know where the bundle is
+					// located. Then, we'll craft the directory by appending
+					// "Contents/Resources/data".
 
-				// That would be /usr/local/share/msxpertsuite/<modulename>/polChemDefs
-				// that is, /usr/local/share/msxpertsuite/massxpert/polChemDefs, for example.
-				testDir.setPath(QString("%1/%2")
-						.arg(MSXPERTSUITE_DATA_DIR)
-						.arg("polChemDefs"));
+					testDir.setPath(QString("%1/../Resources/data/polChemDefs").arg(QCoreApplication::applicationDirPath()));
+
+					//QMessageBox::information(this,
+					//"dir path",
+					//QCoreApplication::applicationDirPath(), QMessageBox::Ok);
+				}
+				else
+				{
+					/////// From the config.h file
+
+					// That would be /usr/local/share/msxpertsuite/<modulename>/polChemDefs
+					// that is, /usr/local/share/msxpertsuite/massxpert/polChemDefs, for example.
+					testDir.setPath(QString("%1/%2")
+							.arg(MSXPERTSUITE_DATA_DIR)
+							.arg("polChemDefs"));
+				}
 
 				if (testDir.exists() && testDir.isAbsolute())
 				{
@@ -503,13 +520,28 @@ namespace msXpSmassXpert
 			}
 			else
 			{
-				/////// From the config.h file
+				if(QSysInfo::productType() == "osx" || QSysInfo::productType() == "macos")
+				{
+					// Well, if we are on MacOSX, then we need to know where the bundle is
+					// located. Then, we'll craft the directory by appending
+					// "Contents/Resources/data".
 
-				// That would be /usr/local/share/msxpertsuite/<modulename>/polSeqs
-				// that is, /usr/local/share/msxpertsuite/massxpert/polSeqs, for example.
-				testDir.setPath(QString("%1/%2")
-						.arg(MSXPERTSUITE_DATA_DIR)
-						.arg("polSeqs"));
+					testDir.setPath(QString("%1/../Resources/data/polSeqs").arg(QCoreApplication::applicationDirPath()));
+
+					//QMessageBox::information(this,
+					//"dir path",
+					//QCoreApplication::applicationDirPath(), QMessageBox::Ok);
+				}
+				else
+				{
+					/////// From the config.h file
+
+					// That would be /usr/local/share/msxpertsuite/<modulename>/polSeqs
+					// that is, /usr/local/share/msxpertsuite/massxpert/polSeqs, for example.
+					testDir.setPath(QString("%1/%2")
+							.arg(MSXPERTSUITE_DATA_DIR)
+							.arg("polSeqs"));
+				}
 
 				// The path must be absolute and must exist.
 
@@ -557,12 +589,27 @@ namespace msXpSmassXpert
 			}
 			else
 			{
+				if(QSysInfo::productType() == "osx" || QSysInfo::productType() == "macos")
+				{
+					// Well, if we are on MacOSX, then we need to know where the bundle is
+					// located. Then, we'll craft the directory by appending
+					// "Contents/Resources/doc".
+
+					testDir.setPath(QString("%1/../doc").arg(QCoreApplication::applicationDirPath()));
+
+					//QMessageBox::information(this,
+					//"dir path",
+					//QCoreApplication::applicationDirPath(), QMessageBox::Ok);
+				}
+				else
+				{
 				/////// From the config.h file
 
 				// That would be /usr/local/share/doc/msxpertsuite
 				// that is, /usr/local/share/doc/msxpertsuite, for example.
 				testDir.setPath(QString("%1")
 						.arg(MSXPERTSUITE_DOC_DIR));
+				}
 
 				// The path must be absolute and must exist.
 
@@ -609,7 +656,7 @@ namespace msXpSmassXpert
 		MainWindow::initializeUserConfig()
 		{
 			// First off, some general concepts.
-			// 
+			//
 			// massXpert should let the user define any polymer chemistry of
 			// his requirement, without needing the root priviledges for
 			// installation of these new data.
@@ -1490,9 +1537,9 @@ namespace msXpSmassXpert
 			configSettingsAct = new QAction(tr("Config &settings"), this);
 			configSettingsAct->setShortcut(tr("Ctrl+S"));
 			configSettingsAct->setStatusTip(tr("Set the configuration"));
-			connect(configSettingsAct, 
-					&QAction::triggered, 
-					this, 
+			connect(configSettingsAct,
+					&QAction::triggered,
+					this,
 					&MainWindow::setConfigSettingsManually);
 
 			// File/Exit
