@@ -292,14 +292,6 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Set the color to be used to configure the new plot widget to be created.
-	void
-		AbstractMultiPlotWnd::setWishedColor(QColor color)
-		{
-			m_wishedColor = color;
-		}
-
-
 	//! Get the graph in the multigraph plot widget.
 	/*!
 
@@ -346,97 +338,20 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Setup the progress feedback infrastructure.
-	/*!
-
-		The progress feedback infrastructure is based on the signal/slot mechanism.
-		This function sets up some variables to the \c mp_statusBarProgressBar member
-		and triggers QApplication::processEvents() to force display of the current
-		progress as indicated by \p currentValue.
-
-		\param msg string containing the initial feedback message.
-
-		\param startValue initial value of the progress range.
-
-		\param endValue last value of the progress range.
-
-		\param currentValue in the progress range.
-
-*/
-	void
-		AbstractMultiPlotWnd::setupFeedback(QString msg, int startValue,
-				int endValue, int currentValue, int logType)
-		{
-			//qDebug() << __FILE__ << __LINE__
-			//<< "Entering" << __FUNCTION__
-			//<< "with message: " << msg
-			//<< "and startValue:" << startValue
-			//<< "and endValue:" << endValue
-			//<< "and currentValue:" << currentValue
-			//<< "and log type:" << logType;
-
-			if(logType & LogType::LOG_TO_CONSOLE)
-			{
-				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "log type to console";
-				MainWindow *mainWindow = static_cast<MainWindow *>(parent());
-				mainWindow->logConsoleMessage(msg);
-			}
-
-			if(logType & LogType::LOG_TO_STATUS_BAR)
-			{
-
-				// This function is actually called to setup and desetup.
-
-				if(startValue == -1 && endValue == -1)
-				{
-					// Hide it.
-					mp_statusBarProgressBar->setVisible(false);
-
-					mp_statusBarProgressBar->setMinimum(-1);
-					mp_statusBarProgressBar->setMaximum(-1);
-					mp_statusBarProgressBar->setValue(-1);
-				}
-				else
-				{
-					// Show it.
-					mp_statusBarProgressBar->setVisible(true);
-
-					mp_statusBarProgressBar->setMinimum(startValue);
-					mp_statusBarProgressBar->setMaximum(endValue);
-
-					if(currentValue != -1)
-						mp_statusBarProgressBar->setValue(currentValue);
-				}
-
-				if(msg.isEmpty())
-				{
-					// Hide it.
-					mp_statusBarLabel->setVisible(false);
-					mp_statusBarLabel->setText("");
-				}
-				else
-				{
-					// Show it.
-					mp_statusBarLabel->setVisible(true);
-					mp_statusBarLabel->setText(msg);
-				}
-			}
-
-			// Process the app events, to refresh the GUI.
-			QApplication::processEvents();
-		}
-
-
 	//! Update the progress feedback using the \p msg string and the \p currentValue value.
 	void
-		AbstractMultiPlotWnd::updateFeedback(QString msg, int currentValue, int logType)
+		AbstractMultiPlotWnd::updateFeedback(QString msg,
+				int currentValue, bool setVisible, int logType,
+				int startValue, int endValue)
 		{
 			//qDebug() << __FILE__ << __LINE__
 			//<< "Entering" << __FUNCTION__
 			//<< "with message: " << msg
-			//<< "and currentValue:" << currentValue
-			//<< "and log type:" << logType;
+			//<< "currentValue:" << currentValue
+			//<< "set visible:" << setVisible
+			//<< "log type:" << logType
+			//<< "startValue:" << startValue
+			//<< "endValue:" << endValue;
 
 			if(logType & LogType::LOG_TO_CONSOLE)
 			{
@@ -446,29 +361,19 @@ namespace msXpSmineXpert
 
 			if(logType & LogType::LOG_TO_STATUS_BAR)
 			{
-				if(currentValue != -1)
-				{
-					// Show it.
-					mp_statusBarProgressBar->setVisible(true);
-					mp_statusBarProgressBar->setValue(currentValue);
-				}
+				mp_statusBarLabel->setVisible(setVisible);
+				mp_statusBarCancelPushButton->setVisible(setVisible);
+				mp_statusBarProgressBar->setVisible(setVisible);
+
+				if(startValue != -1)
+					mp_statusBarProgressBar->setMinimum(startValue);
+				if(endValue != -1)
+					mp_statusBarProgressBar->setMaximum(endValue);
+
+				mp_statusBarProgressBar->setValue(currentValue);
 
 				mp_statusBarLabel->setText(msg);
-
-				if(!msg.isEmpty())
-				{
-					// Show it.
-					mp_statusBarLabel->setVisible(true);
-				}
-				else
-				{
-					// Hide it.
-					mp_statusBarLabel->setVisible(false);
-				}
 			}
-
-			// Process the app events, to refresh the GUI.
-			QApplication::processEvents();
 		}
 
 
@@ -742,6 +647,8 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::cancelPushButtonClicked()
 		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
 			m_isOperationCancelled = true;
 			emit cancelOperationSignal();
 		}
@@ -751,7 +658,7 @@ namespace msXpSmineXpert
 		AbstractMultiPlotWnd::setMzIntegrationParamsWnd(MzIntegrationParamsWnd *wnd)
 		{
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "with params:" << wnd->paramsAsText();
+			//<< "with params:" << wnd->paramsAsText();
 
 			mp_mzIntegrationParamsWnd = wnd;
 		}
@@ -760,8 +667,8 @@ namespace msXpSmineXpert
 		AbstractMultiPlotWnd::updateMzIntegrationParams(MzIntegrationParams params, const QColor &color)
 		{
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< QString::asprintf("\twith params:\n%s\n", params.asText().toLatin1().data())
-				//<< "and color:" << color;
+			//<< QString::asprintf("\twith params:\n%s\n", params.asText().toLatin1().data())
+			//<< "and color:" << color;
 
 			mp_mzIntegrationParamsWnd->updateMzIntegrationParams(params, color);
 		}
@@ -774,7 +681,7 @@ namespace msXpSmineXpert
 			// MzIntegrationParamsWnd.
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "with params:" << params.asText();
+			//<< "with params:" << params.asText();
 
 			// The last focused plot widget needs to "read" the new params and set
 			// them to its history.
