@@ -102,9 +102,9 @@ namespace msXpSmineXpert
 		m_fileName{fileName},
 		m_isMultiGraph{isMultiGraph}
 	{
-		qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			<< "Creating new plot widget:" << this
-			<< "with parent window:" << parent;
+		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+		//<< "Creating new plot widget:" << this
+		//<< "with parent window:" << parent;
 
 		if(parent == Q_NULLPTR)
 			qFatal("Fatal error at %s@%d -- %s(). "
