@@ -91,7 +91,7 @@ namespace msXpSmineXpert
 
 			\sa m_keyRangeStart <br> m_keyRangeEnd.
 			*/
-		double m_lastI = qSNaN();
+		double m_lastTicIntensity = qSNaN();
 
 		//! Left border of the x-axis (abscissae) range selected for TIC intensity calculation.
 		/*!
@@ -137,7 +137,7 @@ namespace msXpSmineXpert
 			user deletes the plot from the TIC chromatogram window.
 
 */
-		MassSpecDataSet *mp_massSpecDataSet = Q_NULLPTR;
+		const MassSpecDataSet *mp_massSpecDataSet = Q_NULLPTR;
 
 
 		//! The name of the data file from which the mass data were read.
@@ -332,7 +332,7 @@ namespace msXpSmineXpert
 		public:
 
 		explicit AbstractPlotWidget(QWidget *parent, const QString &name,
-				const QString &desc, MassSpecDataSet *massSpecDataSet, const QString &fileName = QString(),
+				const QString &desc, const MassSpecDataSet *massSpecDataSet, const QString &fileName = QString(),
 				bool isMultiGraph = false);
 
 		virtual ~AbstractPlotWidget();
@@ -453,6 +453,9 @@ namespace msXpSmineXpert
 		Q_INVOKABLE QList<double> keys();
 		Q_INVOKABLE QList<double> values();
 
+		void setLastTicIntensity(double value);
+		Q_INVOKABLE double lastTicIntensity(void);
+
 		Q_INVOKABLE msXpSlibmass::Trace trace();
 
 signals:
@@ -469,7 +472,7 @@ signals:
 		// This integration is particular and sits in the abstract class because it
 		// can be elicited from any plot widget type (mass, drift, tic).
 
-		void newTicChromatogram(MassSpecDataSet *massSpecDataSet,
+		void newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, const History &history, QColor color);
 	};
 
