@@ -131,11 +131,11 @@ namespace msXpSmineXpert
 		ColorMapWnd::initialColorMap(const MassSpecDataSet *massSpecDataSet,
 				AbstractPlotWidget *originWidget, const QColor &color)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
-				<< " - current thread id:" << QThread::currentThreadId()
-				<< "with massSpecDataSet:" << massSpecDataSet
-				<< "with originalWidget:" << originWidget
-				<< "with color:" << color;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+			//<< " - current thread id:" << QThread::currentThreadId()
+			//<< "with massSpecDataSet:" << massSpecDataSet
+			//<< "with originalWidget:" << originWidget
+			//<< "with color:" << color;
 
 			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -148,8 +148,8 @@ namespace msXpSmineXpert
 			// The integrator will perform the integration itself.
 			MassDataIntegrator *integrator = new MassDataIntegrator(massSpecDataSet);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Allocated new integrator:" << integrator;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Allocated new integrator:" << integrator;
 
 			integrator->moveToThread(thread);
 
@@ -184,14 +184,11 @@ namespace msXpSmineXpert
 					integrator,
 					&MassDataIntegrator::cancelOperation);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< " - current thread id:" << QThread::currentThreadId()
-				<< "going to thread->start()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< " - current thread id:" << QThread::currentThreadId()
+			//<< "going to thread->start()";
 
 			thread->start();
-
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - exit"
-				<< " - current thread id:" << QThread::currentThreadId();
 		}
 
 
@@ -199,9 +196,9 @@ namespace msXpSmineXpert
 		ColorMapWnd::initialColorMapDone(MassDataIntegrator *integrator,
 				AbstractPlotWidget *originWidget, QColor color)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
-				<< " - current thread id:" << QThread::currentThreadId()
-				<< "with color:" << color;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+			//<< " - current thread id:" << QThread::currentThreadId()
+			//<< "with color:" << color;
 
 			const MassSpecDataSet *massSpecDataSet = integrator->massSpecDataSet();
 
@@ -369,8 +366,9 @@ namespace msXpSmineXpert
 			widget->rhistory().copyHistory(localHistory, true /*remove duplicates*/);
 
 			// Finally we can delete the integrator
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Finally deleting the integrator object:" << integrator;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Finally deleting the integrator object:" << integrator;
+
 			delete integrator;
 			integrator = Q_NULLPTR;
 
@@ -440,7 +438,7 @@ namespace msXpSmineXpert
 		ColorMapWnd::ticIntensity(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, History history)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -501,7 +499,7 @@ namespace msXpSmineXpert
 		ColorMapWnd::ticIntensityDone(MassDataIntegrator *integrator, QString msg,
 				AbstractPlotWidget *senderPlotWidget)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			//De-setup the feedback.
 			QTimer::singleShot(2000, this, [=]()
