@@ -722,8 +722,8 @@ namespace msXpSmineXpert
 
 			logConsoleMessage("Done loading file.\n");
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Going to add the tic chrom plot widget to the open spectra dialog.";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Going to add the tic chrom plot widget to the open spectra dialog.";
 
 			// Add a new item to the open spectrum dialog window widget list such
 			// that we'll know which files are open. Note that the function below
@@ -750,8 +750,8 @@ namespace msXpSmineXpert
 				//////////////////////////// COLOR MAP WND //////////////////////////////
 				//////////////////////////// COLOR MAP WND //////////////////////////////
 
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-					<< "Now chaining on to the initial color map stuff";
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "Now chaining on to the initial color map stuff";
 
 				// At this time, we now can compute the initial color map, thus generating
 				// a new plot widget that we will associate to the tic chrom plot widget.
@@ -759,10 +759,10 @@ namespace msXpSmineXpert
 				statusBarMessage("Calculating the Color map...");
 				logConsoleMessage("Calculating the Color map...\n");
 
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-					<< "going to call mp_colorMapWnd->initialColorMap;"
-					<< "with massSpecDataSet:" << massSpecDataSet
-					<< "and filename:" << massSpecDataSet->fileName();
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "going to call mp_colorMapWnd->initialColorMap;"
+				//<< "with massSpecDataSet:" << massSpecDataSet
+				//<< "and filename:" << massSpecDataSet->fileName();
 
 				mp_colorMapWnd->initialColorMap(massSpecDataSet, widget, color);
 
@@ -774,8 +774,8 @@ namespace msXpSmineXpert
 			// But only show the informative dialog if there are multiple spectra in the
 			// data set. Otherwise it does not make sense.
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "checking if we need to display the mz integ params help dialog window";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "checking if we need to display the mz integ params help dialog window";
 
 			if(massSpecDataSet->size() > 1)
 				showMzIntegrationParamsHelp(massSpecDataSet->statistics().m_smallestStepMedian);
@@ -786,8 +786,8 @@ namespace msXpSmineXpert
 		MainWindow::initialColorMapDone(AbstractPlotWidget *widget,
 				AbstractPlotWidget *originWidget, const MassSpecDataSet *massSpecDataSet, QColor color)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
-				<< "current thread id:" << QThread::currentThreadId();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+			//<< "current thread id:" << QThread::currentThreadId();
 
 			if(widget == Q_NULLPTR)
 			{
@@ -1935,7 +1935,7 @@ namespace msXpSmineXpert
 					&QCheckBox::clicked,
 					[=](const bool &isChecked)
 					{
-					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 					QSettings settings;
 					settings.setValue("MainWindow_nomoreShowMzIntegrationParamsHelp", isChecked);
 					});
@@ -2529,7 +2529,7 @@ namespace msXpSmineXpert
 	void
 		MainWindow::seedInitialPlots(MassSpecDataSet *p_massSpecDataSet)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter";
 
 			// Each new plot must have a different color than all the others already
 			// used, such that we can distinguish the files throughout all the
@@ -2569,8 +2569,8 @@ namespace msXpSmineXpert
 				m_colorList.takeFirst();
 			}
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "setting wished color:" << *useColor;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "setting wished color:" << *useColor;
 
 			//qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
 			// Now compute the TIC and plot it. The function returns the plot widget
