@@ -136,7 +136,7 @@ namespace msXpSmineXpert
 
 			// Note that m_xDelta is always fabs().
 
-			if(m_xDelta >= 0.9 && m_xDelta <= 1.1)
+			if(m_xDelta >= 0 && m_xDelta <= 1.1)
 			{
 				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
 				//<< "m_xDelta:" << m_xDelta
@@ -346,6 +346,10 @@ namespace msXpSmineXpert
 			m_keyRangeStart = qSNaN();
 			m_keyRangeEnd = qSNaN();
 
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "m_xRangeMin:" << m_xRangeMin
+				//<< "m_xRangeMax:" << m_xRangeMax;
+
 			if(m_xRangeMax == m_xRangeMin)
 			{
 				//qDebug() << __FILE__ << __LINE__
