@@ -196,8 +196,8 @@ namespace msXpSmineXpert
 */
 	MassSpecPlotWidget *
 		MassSpecWnd::addPlotWidget(const QVector<double> &keyVector, const QVector<double> &valVector,
-				const QString &desc,
-				MassSpecDataSet *massSpecDataSet, bool isMultiGraph)
+				const QString &desc, const QColor &color,
+				const MassSpecDataSet *massSpecDataSet, bool isMultiGraph)
 		{
 			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
 
@@ -246,15 +246,7 @@ namespace msXpSmineXpert
 
 			widget->graph()->setData(keyVector, valVector);
 
-			// Let's see if one color was set as the desired color, otherwise use
-			// black.
-
-			QColor localColor = Qt::black;
-
-			if(m_wishedColor.isValid())
-				localColor = m_wishedColor;
-
-			widget->setPlottingColor(localColor);
+			widget->setPlottingColor(color);
 
 			widget->rescaleAxes(true /*only enlarge*/);
 			widget->replot();
@@ -309,45 +301,78 @@ namespace msXpSmineXpert
 
 */
 	void
-		MassSpecWnd::newMassSpectrum(MassSpecDataSet *massSpecDataSet,
+		MassSpecWnd::newMassSpectrum(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, History history, QColor color)
 		{
+
 			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			m_wishedColor = color;
+			// Plot widget relation between the caller widget and the newly created
+			// widget later on.
+			AbstractPlotWidget *senderPlotWidget = static_cast<AbstractPlotWidget *>(QObject::sender());
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "m_wishedColor:" << color;
-
-			// Make sure the cancel button is visible.
 			mp_statusBarCancelPushButton->setVisible(true);
 
-			MassDataIntegrator integrator(massSpecDataSet, history);
+			// QThread will start the thread in which the integrator will work.
+			QThread* thread = new QThread;
 
-			connect(&integrator,
-					&MassDataIntegrator::setupFeedbackSignal,
+			// The integrator will perform the integration itself.
+			MassDataIntegrator *integrator = new MassDataIntegrator(massSpecDataSet, history);
+
+			integrator->moveToThread(thread);
+
+			// Calling thread->start (QThread::start()) will automatically call the
+			// integrateToMz() function of the integrator.
+			connect(thread, SIGNAL(started()), integrator, SLOT(integrateToMz()));
+
+			// When the integration is finished it emits resultsReadySignal and thus
+			// we can stop the *real* thread in the QThread thread instance, using the
+			// signal/slot mechanism. That is not like calling QThead::quit() !!!
+			connect(integrator, SIGNAL(resultsReadySignal()), thread, SLOT(quit()));
+
+			// This will be needed later, when we'll create a data plot relation
+			// object relating the sender plot widget with the newly created one (in
+			// newMassSpectrumDone).
+			connect(integrator,
+					&MassDataIntegrator::resultsReadySignal,
 					this,
-					&AbstractMultiPlotWnd::setupFeedback);
+					[integrator, senderPlotWidget, color, this] ()
+					{
+					newMassSpectrumDone(integrator,
+							senderPlotWidget, color);
+					}
+					);
 
-			connect(&integrator,
+			connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
+
+			connect(integrator,
 					&MassDataIntegrator::updateFeedbackSignal,
 					this,
 					&AbstractMultiPlotWnd::updateFeedback);
 
 			connect(this,
 					&AbstractMultiPlotWnd::cancelOperationSignal,
-					&integrator,
+					integrator,
 					&MassDataIntegrator::cancelOperation);
 
-			integrator.integrate();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "current thread id:" << QThread::currentThreadId();
 
-			//qDebug() << "At this point the integration is finished. Desetup the feedback.";
+			thread->start();
+		}
+
+
+	void
+		MassSpecWnd::newMassSpectrumDone(MassDataIntegrator *integrator,
+				AbstractPlotWidget *senderPlotWidget, QColor color)
+		{
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			//De-setup the feedback.
 			QTimer::singleShot(2000, this, [=]()
 					{
-					setupFeedback("", -1, -1, -1, LogType::LOG_TO_STATUS_BAR);
+					updateFeedback("", -1, false /* setVisible */, LogType::LOG_TO_STATUS_BAR);
 					}
 					);
 
@@ -356,23 +381,23 @@ namespace msXpSmineXpert
 
 			// Create a text item to indicate the last history item.
 
-			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
+			QString historyItemText = integrator->history().newestHistoryItem()->asText(true /* brief */);
 
 			QString plotText = QString("%1\n%2 - %3 ")
-				.arg(massSpecDataSet->fileName())
+				.arg(integrator->massSpecDataSet()->fileName())
 				.arg(m_desc)
 				.arg(historyItemText);
 
 			// Allocate the new plot widget in which the data are to be plot.
 
 			MassSpecPlotWidget *widget = static_cast<MassSpecPlotWidget *>(
-					addPlotWidget(integrator.keyVector(), integrator.valVector(),
-						plotText, massSpecDataSet));
+					addPlotWidget(integrator->keyVector(), integrator->valVector(),
+						plotText, color, integrator->massSpecDataSet()));
 
 			// The history that we get as a parameter needs to be appended to the new
 			// widget's history so that we have a full account of the history.
 
-			widget->rhistory().copyHistory(history, true /*remove duplicates*/);
+			widget->rhistory().copyHistory(integrator->history(), true /*remove duplicates*/);
 
 			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
 			mainWindow->logConsoleMessage(widget->history().asText(
@@ -413,21 +438,110 @@ namespace msXpSmineXpert
 			connect(widget, &MassSpecPlotWidget::newTicChromatogram,
 					mainWindow->mp_ticChromWnd, &TicChromWnd::newTicChromatogram);
 
-			AbstractPlotWidget *senderPlotWidget =
-				dynamic_cast<AbstractPlotWidget *>(QObject::sender());
-
-			if(senderPlotWidget == Q_NULLPTR)
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+			connect(widget, &MassSpecPlotWidget::ticIntensitySignal,
+					this, &MassSpecWnd::ticIntensity);
 
 			mainWindow->m_dataPlotWidgetRelationer.newRelation(
-					massSpecDataSet, senderPlotWidget, widget,
+					integrator->massSpecDataSet(), senderPlotWidget, widget,
 					Q_NULLPTR /* open spectra dialog list widget item */);
+
+			// Finally we can destroy the integrator.
+			delete integrator;
+		}
+
+
+	void
+		MassSpecWnd::ticIntensity(const MassSpecDataSet *massSpecDataSet,
+				const QString &msg, History history)
+		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			mp_statusBarCancelPushButton->setVisible(true);
+
+			AbstractPlotWidget *senderPlotWidget = static_cast<AbstractPlotWidget *>(QObject::sender());
+
+			// QThread will start the thread in which the integrator will work.
+			QThread* thread = new QThread;
+
+			// The integrator will perform the integration itself.
+			MassDataIntegrator *integrator = new MassDataIntegrator(massSpecDataSet, history);
+
+			integrator->moveToThread(thread);
+
+			// Calling thread->start (QThread::start()) will automatically call the
+			// integrateToTicIntensity() function of the integrator.
+			connect(thread, SIGNAL(started()), integrator, SLOT(integrateToTicIntensity()));
+
+			// When the integration is finished it emits resultsReadySignal and thus
+			// we can stop the *real* thread in the QThread thread instance, using the
+			// signal/slot mechanism. That is not like calling QThead::quit() !!!
+			connect(integrator, SIGNAL(resultsReadySignal()), thread, SLOT(quit()));
+
+			// This will be needed later, when we'll create a data plot relation
+			// object relating the sender plot widget with the newly created one (in
+			// ticIntensityDone).
+			connect(integrator,
+					&MassDataIntegrator::resultsReadySignal,
+					this,
+					[integrator, msg, senderPlotWidget, this] ()
+					{
+					ticIntensityDone(integrator, msg, senderPlotWidget);
+					}
+					);
+
+			connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
+
+			connect(integrator,
+					&MassDataIntegrator::updateFeedbackSignal,
+					this,
+					&AbstractMultiPlotWnd::updateFeedback);
+
+			connect(this,
+					&AbstractMultiPlotWnd::cancelOperationSignal,
+					integrator,
+					&MassDataIntegrator::cancelOperation);
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "current thread id:" << QThread::currentThreadId();
+
+			thread->start();
+		}
+
+
+	void
+		MassSpecWnd::ticIntensityDone(MassDataIntegrator *integrator, QString msg,
+				AbstractPlotWidget *senderPlotWidget)
+		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			//De-setup the feedback.
+			QTimer::singleShot(2000, this, [=]()
+					{
+					updateFeedback("", -1, false /* setVisible */, LogType::LOG_TO_STATUS_BAR);
+					}
+					);
+
+			// Make sure the cancel button is hidden.
+			mp_statusBarCancelPushButton->setVisible(false);
+
+			// Set the proper value in the plot widget right away so that it can be
+			// queried in another context.
+			senderPlotWidget->setLastTicIntensity(integrator->ticIntensity());
+
+			// Now we can dipslay the results in the status bar:
+			statusBar()->showMessage(msg + QString(": TIC int.: %1").arg(integrator->ticIntensity()));
+
+			// Finally we can destroy the integrator.
+			delete integrator;
 		}
 
 
 	void
 		MassSpecWnd::newPlot(AbstractPlotWidget *senderPlotWidget,
-				MassSpecDataSet *massSpecDataSet,
+				const MassSpecDataSet *massSpecDataSet,
 				QVector<double> keys, QVector<double> values,
 				const QString &msg, History history, QColor color)
 		{
@@ -437,8 +551,6 @@ namespace msXpSmineXpert
 			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			m_wishedColor = color;
-
 			// Create a text item to indicate the last history item.
 
 			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
@@ -452,7 +564,7 @@ namespace msXpSmineXpert
 			// Allocate the new plot widget in which the data are to be plot.
 
 			MassSpecPlotWidget *widget = static_cast<MassSpecPlotWidget *>(
-					addPlotWidget(keys, values, plotText, massSpecDataSet));
+					addPlotWidget(keys, values, plotText, color, massSpecDataSet));
 
 			// The history that we get as a parameter needs to be appended to the new
 			// widget's history so that we have a full account of the history.
