@@ -283,9 +283,9 @@ namespace msXpSmineXpert
 	void
 		TicChromWnd::initialTic(const MassSpecDataSet *p_massSpecDataSet, QColor color)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
-				<< " - current thread id:" << QThread::currentThreadId()
-				<< "with color:" << color;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+			//<< " - current thread id:" << QThread::currentThreadId()
+			//<< "with color:" << color;
 
 			if(p_massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s(). "
@@ -301,8 +301,8 @@ namespace msXpSmineXpert
 			// The integrator will perform the integration itself.
 			MassDataIntegrator *integrator = new MassDataIntegrator(p_massSpecDataSet);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Allocated new integrator:" << integrator;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Allocated new integrator:" << integrator;
 
 			integrator->moveToThread(thread);
 
@@ -381,13 +381,14 @@ namespace msXpSmineXpert
 					massSpecDataSet->fileName(),
 					color, massSpecDataSet);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "created a new widget for the tic chromatogram:" << widget
-				<< "with massSpecDataSet:" << massSpecDataSet;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "created a new widget for the tic chromatogram:" << widget
+			//<< "with massSpecDataSet:" << massSpecDataSet;
 
 			// Finally we can delete the integrator
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Finally deleting the integrator object:" << integrator;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Finally deleting the integrator object:" << integrator;
+
 			delete integrator;
 			integrator = Q_NULLPTR;
 
@@ -470,8 +471,8 @@ namespace msXpSmineXpert
 
 			mainWindow->logConsoleMessage(stats.asText(), color);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Statistics: " << massSpecDataSet->statisticsAsText();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Statistics: " << massSpecDataSet->statisticsAsText();
 
 			// The plot widget reacts to the Qt::Key_Delete key by calling a function
 			// that emits a set of signals, of which the destroyPlotWidget signal
@@ -707,7 +708,7 @@ namespace msXpSmineXpert
 		TicChromWnd::ticIntensity(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, History history)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
