@@ -47,6 +47,7 @@
 #include <minexpert/nongui/AnalysisPreferences.hpp>
 #include <minexpert/nongui/MassSpecDataFileLoaderSqlite3.hpp>
 #include <minexpert/nongui/MassSpecDataSet.hpp>
+#include <minexpert/nongui/MassDataIntegrator.hpp>
 
 
 namespace msXpSmineXpert
@@ -103,20 +104,24 @@ namespace msXpSmineXpert
 			TicChromPlotWidget *addPlotWidget(const QVector<double> &keyVector,
 					const QVector<double> &valVector,
 					const QString &desc = QString(),
-					MassSpecDataSet *massSpecDataSet = Q_NULLPTR,
-					bool isMultiGraph = false);
+					const QColor &color = Qt::black,
+					const MassSpecDataSet *massSpecDataSet = Q_NULLPTR,
+					bool isMultiGraph = false) override;
 
-			AbstractPlotWidget *initialTic(MassSpecDataSet *massSpecDataSet);
+			void initialTic(const MassSpecDataSet *massSpecDataSet, QColor color = Qt::black);
 
-			void newTicChromatogram(MassSpecDataSet *massSpecDataSet,
+			void newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, History history, QColor color);
 
+			void ticIntensity(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, History history);
+
 			void newPlot(AbstractPlotWidget *senderPlotWidget,
-					MassSpecDataSet *massSpecDataSet,
+					const MassSpecDataSet *massSpecDataSet,
 					QVector<double> keys, QVector<double> values,
 					const QString &msg, History history, QColor color);
 
-			Q_INVOKABLE void clearPlots();
+			Q_INVOKABLE void clearPlots() override;
 
 			// We do not want to hide the base class function here.
 			using AbstractMultiPlotWnd::toggleMultiGraph;
@@ -124,6 +129,23 @@ namespace msXpSmineXpert
 
 			void recordAnalysisStanza(const QString &stanza,
 					const QColor & color = QColor());
+
+			public slots:
+
+				void initialTicDone(MassDataIntegrator *integrator, QColor color);
+
+			void newTicChromatogramDone(MassDataIntegrator *integrator,
+					AbstractPlotWidget *senderPlotWidget, QColor color);
+
+			void ticIntensityDone(MassDataIntegrator *integrator, QString msg,
+					AbstractPlotWidget *senderPlotWidget);
+
+signals:
+			void integrateToRtSignal();
+			void integrateToTicIntensitySignal();
+			void initialTicDoneSignal(AbstractPlotWidget *widget,
+					const MassSpecDataSet *massSpecDataSet, QColor color);
+
 	};
 
 
