@@ -1651,10 +1651,10 @@ namespace msXpSmineXpert
 			// End of
 			// while(nextSpectrum(&spectrumPtr) != -1)
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "at this point, we parsed all the spectra:"
-				<< "total number of effectively stored spectral:" << m_storedSpectraCount
-				<< "total skipped spectra:" << m_totalSkippedSpectra;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "at this point, we parsed all the spectra:"
+			//<< "total number of effectively stored spectral:" << m_storedSpectraCount
+			//<< "total skipped spectra:" << m_totalSkippedSpectra;
 
 			int rtHashSize = mp_massSpecDataSet->m_rtHash.size();
 			int dtHashSize = mp_massSpecDataSet->m_dtHash.size();
@@ -1680,7 +1680,7 @@ namespace msXpSmineXpert
 				.arg(m_storedSpectraCount)
 				.arg(m_totalSkippedSpectra);
 
-			qDebug() << __FILE__ << __LINE__ << msg.toLatin1();
+			//qDebug() << __FILE__ << __LINE__ << msg.toLatin1();
 
 			emit updateFeedbackSignal(msg, -1, true /* setVisible */,
 					LogType::LOG_TO_BOTH);
