@@ -135,11 +135,10 @@ namespace msXpSmineXpert
 		{
 			if(!history.isValid())
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "The History is not valid. Returning.";
-
-				qFatal("Fatal error at %s@%d. Program aborted.",
-						__FILE__, __LINE__);
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error: the History passed as parameter is not valid."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 
 				return QString();
 			}
@@ -416,11 +415,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery->isActive())
@@ -490,9 +489,8 @@ namespace msXpSmineXpert
 			// we may try to try this function with mass spectra data only.
 			if(dataKind == MassDataKind::DRIFT_SPECTRA && !goneInWhileLoop)
 			{
-				qDebug() << __FILE__ << __LINE__ << "We did not iterate in the query "
-					"results in drift data mode. Retry "
-					"in mass data mode.";
+				qDebug() << __FILE__ << __LINE__
+					<< "We did not iterate in the query results in drift data mode. Retry " "in mass data mode.";
 
 				int newDataKind = MassDataKind::MASS_SPECTRA;
 				newSpectraAllocated =
@@ -858,11 +856,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			// qDebug() << __FILE__ << __LINE__
@@ -1032,11 +1030,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery->isActive())
@@ -1075,11 +1073,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery->isActive())
@@ -1203,11 +1201,11 @@ namespace msXpSmineXpert
 				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead, true /* setVisible */, LogType::LOG_TO_STATUS_BAR,
 						m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-					"emitting update feedback signal with"
-					<< "start value:" << m_progressFeedbackStartValue
-					<< "end value:" << m_progressFeedbackEndValue
-					<< "current value:" << spectraRead;
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//"emitting update feedback signal with"
+				//<< "start value:" << m_progressFeedbackStartValue
+				//<< "end value:" << m_progressFeedbackEndValue
+				//<< "current value:" << spectraRead;
 
 				// qDebug() << __FILE__ << __LINE__ << msg;
 			}
@@ -1351,11 +1349,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery->isActive())
@@ -1584,11 +1582,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery->isActive())
@@ -1813,7 +1811,9 @@ namespace msXpSmineXpert
 
 			if(!file.open(QFile::ReadOnly))
 			{
-				qDebug() << __FILE__ << __LINE__ << "Failed to open file" << fileName;
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					<< "Failed to open file" << fileName;
+
 				return false;
 			}
 
@@ -1891,20 +1891,20 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery.lastError() << "Exiting.\n";
-
-				return -1;
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery.lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery.first())
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery.lastError() << "Exiting.\n";
-
-				return -1;
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery.lastError().text().toLatin1().data());
 			}
 
 			ok = false;
@@ -1949,7 +1949,7 @@ namespace msXpSmineXpert
 		MassSpecDataFileLoaderSqlite3::loadData(QSqlDatabase &database,
 				MassSpecSqlite3Handler &handler, MassSpecDataSet *massSpecDataSet)
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -1990,10 +1990,10 @@ namespace msXpSmineXpert
 			m_progressFeedbackStartValue = 0;
 			m_progressFeedbackEndValue = m_spectrumCount;
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				"emitting update feedback signal with"
-				<< "start value:" << m_progressFeedbackStartValue
-				<< "end value:" << m_progressFeedbackEndValue;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//"emitting update feedback signal with"
+			//<< "start value:" << m_progressFeedbackStartValue
+			//<< "end value:" << m_progressFeedbackEndValue;
 
 			emit updateFeedbackSignal(msg, 0, true /* setVisible */,
 					LogType::LOG_TO_BOTH, m_progressFeedbackStartValue, m_progressFeedbackEndValue);
@@ -2086,10 +2086,10 @@ namespace msXpSmineXpert
 		{
 			if(!history.isValid())
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "The History is not valid. Returning.";
-
-				return -1;
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error: the History passed as parameter is not valid."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 			}
 			//else
 			//{
@@ -2109,8 +2109,8 @@ namespace msXpSmineXpert
 				return streamedDtIntegration(history, keyVector, valVector);
 			else
 			{
-				qDebug() << __FILE__ << __LINE__ << "No valid integration type is "
-					"defined for the data to be produced. Returning.";
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					<< "No valid integration type is defined for the data to be produced. Returning.";
 			}
 
 			return -1;
@@ -2221,7 +2221,7 @@ namespace msXpSmineXpert
 			// to provide feedback to the caller.
 			if(!sqlQuery->first())
 			{
-				qDebug() << __FILE__ << __LINE__
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
 					<< "Failed to get the number of records. Returning.";
 			}
 
