@@ -317,9 +317,9 @@ namespace msXpSmineXpert
 				// This is an easy situation. All we need is to set m_sliceCount to 1.
 				m_sliceCount = 1;
 
-				// qDebug() << __FILE__ << __LINE__
-				// << "Setting m_sliceCount to 1 because
-				// SliceType::SLICE_ZOOMED_REGION";
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "Setting m_sliceCount to 1 because SliceType::SLICE_ZOOMED_REGION"
+				//<< "with m_rangeStart:" << m_rangeStart << "and m_rangeEnd:" << m_rangeEnd;
 			}
 			else if(m_sliceType == SliceType::SLICE_BY_SIZE)
 			{
@@ -358,8 +358,8 @@ namespace msXpSmineXpert
 				//<< "Setting m_sliceSize to" << m_sliceSize;
 			}
 
-			qDebug() << __FILE__ << __LINE__
-				<< "Before making the slicing, SqlMassDataSlicer.asText():" << asText();
+			//qDebug() << __FILE__ << __LINE__
+			//<< "Before making the slicing, SqlMassDataSlicer.asText():" << asText();
 
 			// At this point, m_sliceCount and m_sliceRange will have been filled-up
 			// with proper values.
@@ -392,10 +392,9 @@ namespace msXpSmineXpert
 				// At this point, the name can go to the specif:
 				sliceSpecif->fileName = fileName;
 
-				qDebug() << __FILE__ << __LINE__ << "Slice specif:"
-					<< "[" << sliceSpecif->start << "-" << sliceSpecif->end
-					<< "] ; " << sliceSpecif->fileName;
-				;
+				//qDebug() << __FILE__ << __LINE__ << "Slice specif:"
+				//<< "[" << sliceSpecif->start << "-" << sliceSpecif->end
+				//<< "] ; " << sliceSpecif->fileName;
 
 				// Finally append the sliceSpecif to the list.
 				m_sliceSpecifList.append(sliceSpecif);
@@ -630,7 +629,7 @@ namespace msXpSmineXpert
 					{
 						fileName += QString("%1").arg(sliceSpecif->number);
 
-						qDebug() << __FILE__ << __LINE__ << "fileName: " << fileName;
+						//qDebug() << __FILE__ << __LINE__ << "fileName: " << fileName;
 
 						prevChar = ' ';
 						continue;
@@ -748,8 +747,8 @@ namespace msXpSmineXpert
 				return errors;
 			}
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "allSliceSpecifsAsText:" << allSliceSpecifsAsText();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "allSliceSpecifsAsText:" << allSliceSpecifsAsText();
 
 			for(int iter = 0; iter < sliceSpecifListSize; ++iter)
 			{
@@ -778,8 +777,8 @@ namespace msXpSmineXpert
 
 				emit updateSliceFileName(sliceSpecif->fileName);
 
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__
-					<< "Now handling slice:" << sliceSpecifAsText(sliceSpecif);
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+				//<< "Now handling slice:" << sliceSpecifAsText(sliceSpecif);
 
 				// We need to update *INSIDE, that is IN PLACE* the member History the
 				// last item such that the slicer will have the sliceSpecif range values
@@ -813,8 +812,8 @@ namespace msXpSmineXpert
 				integrationRange->start = sliceSpecif->start;
 				integrationRange->end = sliceSpecif->end;
 
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__
-					<< "m_history as transmitted to the sql handler:" << m_history.asText();
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+				//<< "m_history as transmitted to the sql handler:" << m_history.asText();
 
 				errors = mp_sqlHandler->exportData(m_srcFileName, sliceSpecif->fileName, m_history);
 
